/*
Copyright (c) 2009, 2010, Andreas 'Segaja' Schleifer

Permission to use, copy, modify, and/or distribute this software for any purpose with or
without fee is hereby granted, provided that the above copyright notice and this permission
notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY
DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE
OR PERFORMANCE OF THIS SOFTWARE.
*/


var ts2v_image_plus; // Variable fuer Plus-Bild
var ts2v_image_minus; // Variable fuer Minus-Bild
var ts2v_image_spacer; // Variable fuer Spacer-Bild
var ts2v_time; // Variable fuer Timer
var ts2v_channelLink; // Variable fuer Channellink
var ts2v_XML; // Variable fuer XML

function ts2v_init() { // laed den TS2Viewer
  // Plus-Bild definieren...
  ts2v_image_plus = new Image();
  ts2v_image_plus.src = '/ts2viewer/images/plus.gif';
  ts2v_image_plus.alt = 'Channelinhalt einblenden';

  // Minus-Bild definieren...
  ts2v_image_minus = new Image();
  ts2v_image_minus.src = '/ts2viewer/images/minus.gif';
  ts2v_image_minus.alt = 'Channelinhalt ausblenden';
  
  // Spacer-Bild definere...
  ts2v_image_spacer = new Image();
  ts2v_image_spacer.src = '/ts2viewer/images/spacer.gif';
  ts2v_image_spacer.alt = '';
}

function ts2v_load() { // laedt die Daten mit AJAX
  if(ts2v_time) { // Timer clearen, wenn vorhanden...
    window.clearTimeout(ts2v_time);
  }

  if(!document.getElementById('ts2viewer')) { // end here if object for TS2Viewer not present...
    return;
  }

  if(ts2v_image_plus == null) { // init images for TS2Viewer if not defined,,,
    ts2v_init();
  }

  new xml.InterXml('ts2viewer/core/ts2viewer.php', ts2v_parse, true); // retrieve TS2Viewer data and show it
}

function ts2v_parse() { // verarbeitet die XML Daten
  var ts2viewer = document.getElementById('ts2viewer'); // Container fuer TS2Viewer holen

  if(!ts2viewer) { // wenn Container nicht vorhanden ist...
    return; // abbrechen...
  }

  while(ts2viewer.lastChild) { // div-tag leeren...
    ts2viewer.removeChild(ts2viewer.lastChild);
  }

  if(!this.responseXML) { // XML nicht vorhanden...
    ts2viewer.appendChild(document.createTextNode('TeamSpeak2-Server offline'));

    return;
  }
 
  ts2v_XML = this.responseXML.documentElement; // XML document of teamspeak server
  var serverinfos = ts2v_evalXPath(ts2v_XML, 'serverinfos', 'node');
  var configs = ts2v_evalXPath(ts2v_XML, 'configs', 'node');

  var reload_time = parseInt(ts2v_evalXPath(configs, 'reload_time', 'integer'));

  if(reload_time > 0) {
    ts2v_time = window.setTimeout(ts2v_load, reload_time * 1000);
  }

  // --- Titel und Welcomemessage aus XML lesen und in titeldiv einfuegen - Anfang ---
  // div-tag fuer Titel erstellen...
  var titeldiv = document.createElement('div');
  titeldiv.className = 'ts2v_titel';

  // server titel setzen...
  var title = (ts2v_evalXPath(serverinfos, 'server_name', 'string') || ts2v_evalXPath(configs, 'default_server_title', 'string'));

  // server link hinzufuegen, wenn erwuenscht...  
  if(ts2v_evalXPath(configs, 'add_channel_links', 'integer') == 1) {
    ts2v_channelLink = 'teamspeak://' + ts2v_evalXPath(configs, 'host', 'string') + ':' + ts2v_evalXPath(serverinfos, 'server_udpport', 'integer');

    var titellink = document.createElement('a');
    titellink.className = 'ts2v_link';
    titellink.href = ts2v_channelLink;
    titellink.appendChild(document.createTextNode(title));
  
    titeldiv.appendChild(titellink);
  }
  else {
    titeldiv.appendChild(document.createTextNode(title));
  }

  if(ts2v_evalXPath(configs, 'set_window_title', 'integer') == 1) { // window titel setzen wenn erwuenscht...
    document.title = title;
  }

  // welcome message anzeigen wenn erwuenscht...
  if(ts2v_evalXPath(configs, 'show_welcome_message', 'integer') == 1) {
    var server_welcomemessage = ts2v_evalXPath(serverinfos, 'server_welcomemessage', 'string');

    if(server_welcomemessage != '') {
      welcomemessagediv = document.createElement('span');
      welcomemessagediv.className = 'ts2v_welcomemessage';
      welcomemessagediv.appendChild(document.createTextNode(' (' + server_welcomemessage + ')'));
	    
      titeldiv.appendChild(welcomemessagediv);
    }
  }

  ts2viewer.appendChild(titeldiv); // titeldiv in root element einhaengen
  // --- Titel und Welcomemessage aus XML lesen und in titeldiv einfuegen - Ende ---

  var channels = ts2v_evalXPath(ts2v_XML, 'channels/channel', 'nodes'); // Channels holen

  for(var chan = 0; chan < channels.length; ++chan) {
    ts2v_output_channel(ts2viewer, channels[chan], configs);
  }
}

function ts2v_output_channel(parentNode, channel, configs) { // Channel in Parent einhaengen und anzeigen
  var children = ts2v_evalXPath(channel, 'children/channel', 'nodes');
  var users = ts2v_evalXPath(channel, 'users/user', 'nodes');

  // div-tag fuer Channel erstellen...
  var chandiv = document.createElement('div');
  chandiv.className = 'ts2v_channel';

  // --- chanpic verarbeiten - Anfang ---
  if(ts2v_evalXPath(configs, 'allow_channel_hiding', 'integer') == 1) {
    if(children.length > 0 || users.length > 0) {
      var chanpic = document.createElement('img');
      chanpic.className = 'ts2v_channel_pic';
      chanpic.title = ts2v_image_minus.alt;
      chanpic.src = ts2v_image_minus.src;
      chanpic.alt = ts2v_image_minus.alt;
      chanpic.onclick = ts2v_hideChannelContent;
    } 
    else {
      var chanpic = document.createElement('img');
      chanpic.className = 'ts2v_channel_pic_spacer';
      chanpic.src = ts2v_image_spacer.src;
      chanpic.alt = ts2v_image_spacer.alt;
    }
    
    chandiv.appendChild(chanpic);
  }
  // --- chanpic verarbeiten - Ende ---

  // Name des Channels verarbeiten...
  var channame = ts2v_evalXPath(channel, 'name', 'string');
    
  if(ts2v_evalXPath(configs, 'add_channel_links', 'integer') == 1) {
    var channode = document.createElement('a');
    channode.className = 'ts2v_link';
    channode.href = ts2v_channelLink + '?channel=' + channame;
    channode.appendChild(document.createTextNode(channame));
  }
  else {
    var channode = document.createTextNode(channame);
  }

  chandiv.appendChild(channode);


  // Topic des Channels verarbeiten...
  if(ts2v_evalXPath(configs, 'show_channel_topics', 'integer') == 1) {
    var topic = ts2v_evalXPath(channel, 'topic', 'string');

    if(topic != '') {
      var topicdiv = document.createElement('span');
      topicdiv.className = 'ts2v_channel_topic';
      topicdiv.appendChild(document.createTextNode(' (' + topic + ')'));

      chandiv.appendChild(topicdiv);
    }
  }

  // --- Channel Flags verarbeiten - Anfang ---
  if(ts2v_evalXPath(configs, 'show_channel_flags', 'integer') == 1) {
    var flags_array = new Array(16);
    flags_array[1] = 'U';
    flags_array[2] = 'M';
    flags_array[4] = 'P';
    flags_array[8] = '';
    flags_array[16] = 'D';
	
    var flags_string = '';

    var flags = ts2v_evalXPath(channel, 'flags', 'integer');
	
    for(i = 4; i >= 0; --i) {
      flags = flags - Math.pow(2, i);
	    
      if(flags < 0) {
        flags += Math.pow(2, i);
      }
      else {
        flags_string += flags_array[Math.pow(2, i)];
      }
    }
	
    if(children.length > 0) {
      flags_string += 'S';
    }
	
    if(flags_string.search('U') == -1) {
      flags_string = 'R'+flags_string;
    }
	
    if(flags_string) {
      var flagsdiv = document.createElement('span');
      flagsdiv.className = 'ts2v_channel_flags';
      flagsdiv.appendChild(document.createTextNode(' (' + flags_string + ')'));
	    
      chandiv.appendChild(flagsdiv);
    }
  }
  // --- Channel Flags verarbeiten - Ende ---

  // Children des Channels verarbeiten...
  if(children.length > 0) {
    var chancontent = document.createElement('div');
    chancontent.className = 'ts2v_channelcontent';

    for(child = 0; child < children.length; ++child) {
      ts2v_output_channel(chancontent, children[child], configs);
    }
  }

  // User des Channels verarbeiten...
  if(users.length > 0) {
    if(!chancontent) {
      var chancontent = document.createElement('div');
      chancontent.className = 'ts2v_channelcontent';
    }

    for(user = 0; user < users.length; ++user) {
      ts2v_output_user(chancontent, users[user], configs);
    }
  }

  if(chancontent) {
    chandiv.appendChild(chancontent);
  }

  parentNode.appendChild(chandiv); // Channel-div in Parent einhaengen
}

function ts2v_output_user(channel, user, configs) { // User in Channel einhaengen und anzeigen
  // div-tag fuer User erstellen...
  var userdiv = document.createElement('div');
  userdiv.className = 'ts2v_user';

  userdiv.appendChild(document.createTextNode(ts2v_evalXPath(user, 'nick', 'string'))); // Nick des Users einfuegen

  // --- Player Rechte / Channel Rechte verarbeiten - Anfang ---
  if(ts2v_evalXPath(configs, 'show_user_flags', 'item') == 1) {
    var pprivs = ts2v_evalXPath(user, 'pprivs', 'integer');
	
    var rechte_array = new Array(16);
    rechte_array[1] = 'SA';
    rechte_array[2] = '';
    rechte_array[4] = 'R';
	
    var rechte = '';
	
    for(i = 4; i >= 0; --i) {
      pprivs = pprivs - Math.pow(2, i);
	    
      if(pprivs < 0) {
        pprivs += Math.pow(2, i);
      }
      else {
        rechte += ' '+rechte_array[Math.pow(2, i)];
      }
    }
	
    if(rechte.search('R') == -1) {
      rechte = ' U'+rechte;
    }
	
    var cprivs = ts2v_evalXPath(user, 'cprivs', 'integer');
	
    rechte_array[1] = 'CA';
    rechte_array[2] = 'O';
    rechte_array[4] = 'V';
    rechte_array[8] = 'AO';
    rechte_array[16] = 'AV';
	
    for(i = 4; i >= 0; --i) {
      cprivs = cprivs - Math.pow(2, i);
	    
      if(cprivs < 0) {
        cprivs += Math.pow(2, i);
      }
      else {
        rechte += ' '+rechte_array[Math.pow(2, i)];
      }
    }
	
    if(rechte) {
      var rechtediv = document.createElement('span');
      rechtediv.className = 'ts2v_user_pprivs';
      rechtediv.appendChild(document.createTextNode(' (' + rechte.substring(1) + ')'));
	    
      userdiv.appendChild(rechtediv);
    }
  }
  // --- Player Rechte / Channel Rechte verarbeiten - Ende ---

  channel.appendChild(userdiv); // user-div in Channel einhaengen
}

function ts2v_hideChannelContent(event) { // blendet den Inhalt eines Channels aus
  if(!event) { // IE?...
    event = window.event;
  }

  var clicked = (event.srcElement ? event.srcElement : event.target); // get clicked node

  // change image...
  clicked.src = ts2v_image_plus.src;
  clicked.alt = ts2v_image_plus.alt;
  clicked.title = ts2v_image_plus.alt;
  clicked.onclick = ts2v_showChannelContent;
    
  getElementsByClassName('ts2v_channelcontent', clicked.parentNode)[0].style.display = 'none';
}

function ts2v_showChannelContent(event) { // blendet den Inhalt eines Channels ein
  if(!event) { // IE?...
    event = window.event;
  }

  var clicked = (event.srcElement ? event.srcElement : event.target); // get clicked node

  // change image...
  clicked.src = ts2v_image_minus.src;
  clicked.alt = ts2v_image_minus.alt;
  clicked.title = ts2v_image_minus.alt;
  clicked.onclick = ts2v_hideChannelContent;

  getElementsByClassName('ts2v_channelcontent', clicked.parentNode)[0].style.display = '';
}

function ts2v_evalXPath(struktur, query, type) {
  if(type == 'string' || type == 'integer') {
    var ret = struktur.selectSingleNode(query);

    if(ret && ret.firstChild) {
      return ret.firstChild.nodeValue;
    }
    else {
      return (type == 'string') ? '' : 0;
    }
  }
  else if(type == 'nodes') {
    return struktur.selectNodes(query);
  }
  else if(type == 'node') {
    return struktur.selectSingleNode(query);
  }
}

if(document.implementation.hasFeature('XPath', '3.0')) {
  Document.prototype.selectNodes = function(xpath, node) {
    if(!node) {
      node = this;
    }

    var result = this.evaluate(xpath, node, this.createNSResolver(this.documentElement), XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, null);

    for(var items = [], i = 0, len = result.snapshotLength; i < len; i++) {
      items.push(result.snapshotItem(i));
    }

    return items;
  };

  Document.prototype.selectSingleNode = function(xpath, node) {
    var xItems = this.selectNodes(xpath, node);

    return xItems[0] || null;
  };

  Element.prototype.selectNodes = function(xpath) {
    return this.ownerDocument.selectNodes(xpath, this);
  };

  Element.prototype.selectSingleNode = function(xpath){   
    return this.ownerDocument.selectSingleNode(xpath, this);
  };
}

if(typeof getElementsByClassName == 'undefined') {
  function getElementsByClassName(className, rootNode) { // liefert alle ChildNodes von rootNode, die className als class haben
    var nodes = rootNode.getElementsByTagName('*');
    var result = [];

    for(var i = 0, node; node = nodes.item(i); ++i) {
      if(node.className.indexOf(className) > -1) {
	result.push(node);
      }
    }
    
    return result;
  }
}

/**
 * This method loads the given css file to the current page.
 */
function ts2v_loadCSS(cssfile) {
  // create css link tag with selected style and add it to the document...
  var styletag = document.createElement('link');
  styletag.type = 'text/css';
  styletag.rel = 'stylesheet';
  styletag.media = 'all';
  styletag.href = cssfile;

  document.getElementsByTagName('head').item(0).appendChild(styletag);
}
