<?
/*
Copyright (c) 2009, 2010, Andreas 'Segaja' Schleifer

Permission to use, copy, modify, and/or distribute this software for any purpose with or
without fee is hereby granted, provided that the above copyright notice and this permission
notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY
DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE
OR PERFORMANCE OF THIS SOFTWARE.
*/

// --- Server Konfiguration / server configuration - Anfang / Begin ---

/* Hostname oder IP-Adresse des TeamSpeak-Servers
 * ---
 * Hostname of ip address of the teamseak server
 */
$host = 'justbase.fm';

/* QueryPort des TeamSpeak-Servers (Standard: 51234)
 * ---
 * query port of the teamspeak server {default: 51234}
 */
$queryport = 51234;

/* UDP-Port des TeamSpeak-Servers (Standard: 8767). Das ist auch der Port, ueber den die User connecten
 * ---
 * udp-port of the teamspeak server {default 8767}. This is also the port, which users use to connect.
 */
$udpport = 8767;

// --- Server Konfiguration / server configuration - Ende / End ---



// --- TS2Viewer Konfiguraion / TS2Viewer configuration - Anfang / Begin ---

/* Zeit (in Sekunden) nachdem der TS2Viewer automatisch die Ansicht aktualisieren soll.
 * 0 = TS2Viewer wird gar nicht neu geladen.
 * ---
 * Time (in sekonds) after which the TS2Viewer reloads the view.
 * 0 = TS2Viewer will not be reloaded at all.
 */
$configs['reload_time'] = 5;

/* Standard Titel des Teampeak-Servers festlegen.
 * Der standard Titel wird angezeigt, wenn kein Titel im Server definiert ist.
 * ---
 * Default title of the teamspeak server.
 * The default title will be displayed, if there is no title defined on the teamspeak server.
 */
$configs['default_server_title'] = 'TeamSpeak-Server';

/* Gibt an, ob die Welcome-Message des TeamSpeak-Servers angezeigt werden soll, wenn sie definiert ist.
 * Wenn ja erscheint hinter dem Namen des TeamSpeak-Servers die Welcome-Message, wenn diese im Teamspeak-Server definiert ist.
 *
 * 1 = Welcome-Message wird anzeigen wenn sie definiert ist
 * 0 = Welcome-Message wird nicht anzeigen
 * ---
 * Defines whether or not the welcome message of the teamspeak server should be displayed, if it is defined.
 * If this option is set to 1 and there is a welcome message defined on the teamspeak server,
 * it will be displayed after the title of the teamspeak server.
 * 
 * 1 = welcome message will be displayed if defined
 * 0 = welcome message will not be displayed
 */
$configs['show_welcome_message'] = 1;

/* Gibt an, ob die Topics der Channels neben den Channelnamen angegeben werden sollen, wenn sie definiert sind.
 * Wenn ja erscheint hinter dem Channel-Namen das Topic, wenn dieses im TeamSpeak-Server definiert ist.
 *
 * 1 = Channel-Topics anzeigen wenn sie definiert sind
 * 0 = Channel-Topics nicht anzeigen
 * ---
 * Defines whether or not the topic of the channels should be displayed, if they are defined.
 * If this option is set to 1 and there is a topic for a channel, it will be displayed after the channel name.
 * 
 * 1 = channel topics will be displayed if they are defined
 * 0 = channel topics will not be displayed
 */
$configs['show_channel_topics'] = 1;

/* Gibt an, ob die Flags der Channels angezeigt werden sollen.
 * Wenn ja erscheint hinter dem Namen und eventuell hinter dem Topic des Channels,
 * wenn es vorhanden und aktiviert ist, die Channel-Flags in Klammern.
 *
 * 1 = Channel-Flags anzeigen
 * 0 = Channel-Flags nicht anzeigen
 * ---
 * Defines whether or not the flags of the channels should be displayed.
 * If this option is set to 1 the channel flags will be displayed in brackets after the name and if active the topic of the channel.
 * 
 * 1 = channel flags will be displayed
 * 0 = channel flags will not be displayed
 */
$configs['show_channel_flags'] = 1;

/* Gibt an, ob die Flags der Users angezeigt werden sollen.
 * Wenn ja erscheinen hinter dem Namen des Users die User-Flags in Klammern.
 *
 * 1 = User-Flags anzeigen
 * 0 = User-Flags nicht anzeigen
 * ---
 * Defines wheterh or not the flags of the users should be displayed.
 * If this option is set to 1 the user flags will be displayed in brackets after the name of the user.
 * 
 * 1 = user flags will be displayed
 * 0 = user flags will not be displayed
 */
$configs['show_user_flags'] = 1;

/* Gibt an, ob es fuer Nutzer moeglich sein soll Child-Channel und User in Channeln durch ein "-" vor dem Parent Channel zu hiden.
 * Wenn ja erscheint vor dem Namen des Parentchannel ein "-" Bild, und durch einen Klick darauf wird der Inhalt des Channels eingeklappt.
 * Dann wird das "-" zu einem "+" und bei einem weiteren Klick wird der Inhalt wieder aufgeklappt.
 *
 * 1 = erlaubt das einklappen von Channels
 * 0 = erlaubt das einklappen von Channels nicht
 * ---
 * Defines whether or not it should be possible for users to hide children channels of a parent channel with a "-" in front of the parent channel.
 * If this option is set to 1 a "-" image appears in front of the parent channel and with a click on it the content of the parent channel
 * will be hidden and the "-" will be replaced by a "+". Another click on the "+" will show the content of the channel again and the "+"
 * will be replaced by a "-".
 * 
 * 1 = channel hiding is allowed
 * 0 = channel hiding is not allowed
 */
$configs['allow_channel_hiding'] = 1;

/* Gibt an, ob der TS2Viewer den Titel des Fensters, indem er angezeigt wird auf den Namen des TeamSpeak-Servers setzen soll.
 * Wenn ja schreibt der TS2Viewer beim Laden den Titel der Seite, in die er eingebunden wird neu.
 * HINWEIS: Diese Funktion sollte man nicht nutzen, wenn man den TS2Viewer in eine vorhandene Seite nur einfuegt,
 * da dann der alte Titel der Seite ueberschrieben wird. Nutzt man den TS2Viewer dagegen alleine auf eine Seite dann ist diese Option sinvoll.
 *
 * 1 = TS2Viewer setzt Fenstertitel
 * 0 = TS2Viewer setzt Fenstertitel nicht
 * ---
 * Defines whether or not the TS2Viewer sets the title of the window it is displayed in to the name of the teamspeak server.
 * If this option is set to 1 the TS2Viewer will set the title of the page it is included in when it loads.
 * ATTENTION: This option should not be used if the TS2Viewer is included in a predefined page, because than the old page title will be replaced.
 * However, if the TS2Viewer is used on a stand alone page this option is reasonable.
 * 
 * 1 = TS2Viewer will set window title
 * 0 = TS2Viewer will not set window title
 */
$configs['set_window_title'] = 1;

/* Gibt an, ob die Channelnamen ein Link zum Teamspeak hinzugefuegt wird.
 * Damit das funktioniert muss im TeamSpeak Server eingestelt sein, das anonyme User in registrierte Channel joinen koennen.
 *
 * 1 = Links werden eingebaut
 * 0 = Links werden nicht eingebaut
 * ---
 * Defines whether or not the channel names will be a link tot the teamspeak server.
 * For this option to work the teamspeak server must allow anonymous users to join into registered channels.
 * 
 * 1 = channel title will be links
 * 0 = channel titles will not be links
 */
$configs['add_channel_links'] = 1;

// --- TS2Viewer Konfiguraion / TS2Viewer configuration - Ende / End ---
?>
